==> haskell-exceptions-0.10.2-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: exceptions
version: 0.10.2
id: exceptions-0.10.2-5svhVYbSwFFKlwgRdeEWGk
key: exceptions-0.10.2-5svhVYbSwFFKlwgRdeEWGk
license: BSD-3-Clause
copyright: Copyright (C) 2013-2015 Edward A. Kmett
           Copyright (C) 2012 Google Inc.
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/exceptions/
synopsis: Extensible optionally-pure exceptions
description:
    Extensible optionally-pure exceptions.
category: Control, Exceptions, Monad
abi: 60f8a7f8aefa2789ebd05fae17b41a75
exposed: True
exposed-modules:
    Control.Monad.Catch Control.Monad.Catch.Pure
import-dirs: /usr/lib/ghc-8.6.5/site-local/exceptions-0.10.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/exceptions-0.10.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/exceptions-0.10.2
hs-libraries: HSexceptions-0.10.2-5svhVYbSwFFKlwgRdeEWGk
depends:
    base-4.12.0.0 mtl-2.2.2 stm-2.5.0.0 template-haskell-2.14.0.0
    transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
haddock-interfaces: /usr/share/doc/haskell-exceptions/html/exceptions.haddock
haddock-html: /usr/share/doc/haskell-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-exceptions-0.10.2-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: exceptions
version: 0.10.2
id: exceptions-0.10.2-F5iQJa9RoWHAiWKkKHwe3
key: exceptions-0.10.2-F5iQJa9RoWHAiWKkKHwe3
license: BSD-3-Clause
copyright: Copyright (C) 2013-2015 Edward A. Kmett
           Copyright (C) 2012 Google Inc.
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/exceptions/
synopsis: Extensible optionally-pure exceptions
description:
    Extensible optionally-pure exceptions.
category: Control, Exceptions, Monad
abi: f79c8f28e400a22078b1e2de5657265b
exposed: True
exposed-modules:
    Control.Monad.Catch Control.Monad.Catch.Pure
import-dirs: /usr/lib/ghc-8.6.5/site-local/exceptions-0.10.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/exceptions-0.10.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/exceptions-0.10.2
hs-libraries: HSexceptions-0.10.2-F5iQJa9RoWHAiWKkKHwe3
depends:
    base-4.12.0.0 mtl-2.2.2 stm-2.5.0.0 template-haskell-2.14.0.0
    transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
haddock-interfaces: /usr/share/doc/haskell-exceptions/html/exceptions.haddock
haddock-html: /usr/share/doc/haskell-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
